@@ -69,7 +69,7 @@ def parse_args(action, usage):
             args.duration = play_actions.parse_duration(args)
 
         if not args.profile and not args.print:
-            print('Download profile must be specified. Use one of: --video --audio')
+            print("Download profile must be specified. Use one of: --video --audio")
             raise SystemExit(1)
 
     if args.db:
@@ -122,11 +122,11 @@ def construct_query(args) -> Tuple[str, dict]:
             {', p.dl_config' if 'dl_config' in pl_columns else ''}
             , coalesce(p.category, p.ie_key) category
         FROM media
-        JOIN playlists p on {db.get_playlists_join(args)}
+        LEFT JOIN playlists p on {db.get_playlists_join(args)}
         WHERE 1=1
             and (media.time_downloaded=0 OR media.time_modified > media.time_downloaded)
             and media.time_deleted=0
-            and p.time_deleted=0
+            and (p.time_deleted is null or p.time_deleted=0)
             {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
             {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
             {args.sql_filter}
