@@ -23,8 +23,14 @@ class MrSuperDialogue:
         self.action = "DELETE"
         self.root.destroy()
 
-    def move_window(self, window_width=200, window_height=180):
-        self.root.geometry("{}x{}+{}+{}".format(window_width, window_height, 0, 0))
+    def move_window(self, window_width=None, window_height=None, x=None, y=None):
+        s_width = window_width or self.root.winfo_screenwidth()
+        s_height = window_height or self.root.winfo_screenheight()
+
+        window_width, window_height = 380, 150  # override
+        x_coordinate = x or 0
+        y_coordinate = y or 0
+        self.root.geometry("{}x{}+{}+{}".format(window_width, window_height, x_coordinate, y_coordinate))
         self.root.update_idletasks()
 
         log.info(
@@ -40,14 +46,12 @@ class MrSuperDialogue:
         # current_screen = self.get_monitor_from_coord(self.winfo_x(), self.winfo_y())
         # current_screen.name
 
-        s_width = self.root.winfo_screenwidth()
-        s_height = self.root.winfo_screenheight()
-        x_coordinate = int((s_width / 2) - (window_width / 2))
-        y_coordinate = int((s_height / 2) - (window_height / 2))
+        x_coordinate = x_coordinate + int((s_width / 2) - (window_width / 2))
+        y_coordinate = y_coordinate + int((s_height / 2) - (window_height / 2))
         self.root.geometry("{}x{}+{}+{}".format(window_width, window_height, x_coordinate, y_coordinate))
         self.root.wm_attributes("-alpha", 1)
 
-    def __init__(self, path, qty):
+    def __init__(self, path, qty, geom_data=None):
         def raise_error(self, *args):
             raise  # pylint: disable=misplaced-bare-raise
 
@@ -110,7 +114,7 @@ class MrSuperDialogue:
         for keyseq in ("k", "y", "2", "\\"):
             self.root.bind(keyseq, lambda _ev: self.keep())
 
-        self.move_window()
+        self.move_window(*(geom_data or []))
         self.root.mainloop()
 
     @staticmethod
@@ -133,8 +137,8 @@ class MrSuperDialogue:
         return monitors[0]
 
 
-def askkeep(path, qty):
-    ex = MrSuperDialogue(path, qty)
+def askkeep(path, qty, geom_data=None):
+    ex = MrSuperDialogue(path, qty, geom_data)
     return ex.action
 
 
